==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/kinesis_analytics_application/KinesisAnalyticsApplicationInputsProcessingConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.kinesis_analytics_application;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.421Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.kinesisAnalyticsApplication.KinesisAnalyticsApplicationInputsProcessingConfiguration")
@software.amazon.jsii.Jsii.Proxy(KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface KinesisAnalyticsApplicationInputsProcessingConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * lambda block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kinesis_analytics_application#lambda KinesisAnalyticsApplication#lambda}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda getLambda();

    /**
     * @return a {@link Builder} of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<KinesisAnalyticsApplicationInputsProcessingConfiguration> {
        com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda;

        /**
         * Sets the value of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration#getLambda}
         * @param lambda lambda block. This parameter is required.
         *               Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/kinesis_analytics_application#lambda KinesisAnalyticsApplication#lambda}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lambda(com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda) {
            this.lambda = lambda;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public KinesisAnalyticsApplicationInputsProcessingConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements KinesisAnalyticsApplicationInputsProcessingConfiguration {
        private final com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lambda = software.amazon.jsii.Kernel.get(this, "lambda", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lambda = java.util.Objects.requireNonNull(builder.lambda, "lambda is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda getLambda() {
            return this.lambda;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("lambda", om.valueToTree(this.getLambda()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.kinesisAnalyticsApplication.KinesisAnalyticsApplicationInputsProcessingConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy that = (KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy) o;

            return this.lambda.equals(that.lambda);
        }

        @Override
        public final int hashCode() {
            int result = this.lambda.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/kinesis_analytics_application/KinesisAnalyticsApplicationInputsProcessingConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.kinesis_analytics_application;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.239Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.kinesisAnalyticsApplication.KinesisAnalyticsApplicationInputsProcessingConfiguration")
@software.amazon.jsii.Jsii.Proxy(KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface KinesisAnalyticsApplicationInputsProcessingConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * lambda block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kinesis_analytics_application#lambda KinesisAnalyticsApplication#lambda}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda getLambda();

    /**
     * @return a {@link Builder} of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<KinesisAnalyticsApplicationInputsProcessingConfiguration> {
        com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda;

        /**
         * Sets the value of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration#getLambda}
         * @param lambda lambda block. This parameter is required.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/kinesis_analytics_application#lambda KinesisAnalyticsApplication#lambda}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lambda(com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda) {
            this.lambda = lambda;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public KinesisAnalyticsApplicationInputsProcessingConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link KinesisAnalyticsApplicationInputsProcessingConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements KinesisAnalyticsApplicationInputsProcessingConfiguration {
        private final com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda lambda;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lambda = software.amazon.jsii.Kernel.get(this, "lambda", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lambda = java.util.Objects.requireNonNull(builder.lambda, "lambda is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.kinesis_analytics_application.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda getLambda() {
            return this.lambda;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("lambda", om.valueToTree(this.getLambda()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.kinesisAnalyticsApplication.KinesisAnalyticsApplicationInputsProcessingConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy that = (KinesisAnalyticsApplicationInputsProcessingConfiguration.Jsii$Proxy) o;

            return this.lambda.equals(that.lambda);
        }

        @Override
        public final int hashCode() {
            int result = this.lambda.hashCode();
            return result;
        }
    }
}
